game_qu.base API documentation
Description: This module holds nearly everything that is not either math or part of the gui. It holds a way to work with the keyboard, utility functions, events, etc.

# Module `game_qu.base`

This module holds nearly everything that is not either math or part of the gui. It holds a way to work with the keyboard, utility functions, events, etc.

Expand source code

    """This module holds nearly everything that is not either math or part of the gui. It holds a way to work with the keyboard,
     utility functions, events, etc."""

## Sub-modules

`game_qu.base.colors`

  Has many RGB colors, but these colors do not have to be used as any RGB color works with drawing shapes

`game_qu.base.count_event`
`game_qu.base.engines`
`game_qu.base.events`
`game_qu.base.file_reader`
`game_qu.base.fraction`
`game_qu.base.game_movement`
`game_qu.base.game_runner_function`
`game_qu.base.history_keeper`
`game_qu.base.id_creator`
`game_qu.base.important_constants`

  Some important constants for the game. None of these values should be changed unless you know what you are doing.

`game_qu.base.important_variables`

  Holds all the important variables for the game like screen_dimensions, BACKGROUND_COLOR, etc

`game_qu.base.keyboard`
`game_qu.base.library_changer`
`game_qu.base.library_independant_utility_functions`
`game_qu.base.lines`
`game_qu.base.paths`
`game_qu.base.quadratic_equations`
`game_qu.base.range`
`game_qu.base.timed_event`
`game_qu.base.unique_ids_list`

  A list of unique identifiers. This can be used for the HistoryKeeper to make hashing quicker and safer (the list is only so long however).

`game_qu.base.utility_functions`
`game_qu.base.velocity_calculator`